#
# spec file for package php-pear-Net_LDAP2
#
# Copyright (c) 2019 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pear_name  Net_LDAP2

Name:           php-pear-Net_LDAP2
Version:        2.2.0
Release:        bp154.1.19
Summary:        Object oriented interface for searching and manipulating LDAP-entries
License:        LGPL-3.0-only
Group:          Development/Libraries/Other
URL:            https://pear.php.net/package/%{pear_name}
Source:         https://pear.php.net/get/%{pear_name}-%{version}.tgz
BuildRequires:  php-devel
BuildRequires:  php-pear
Requires:       php-ldap
Requires:       php-pear
Provides:       php-pear(%{pear_name}) = %{version}
# PHP5 last used in openSUSE:Leap_42.3
Provides:       php5-pear-%{pear_name} = %{version}
Obsoletes:      php5-pear-%{pear_name} < %{version}
Provides:       php7-pear-%{pear_name} = %{version}
Obsoletes:      php7-pear-%{pear_name} < %{version}
BuildArch:      noarch

%description
Net_LDAP2 is the successor of Net_LDAP which is a clone of Perls Net::LDAPobject interface to directory servers.
It does contain most of Net::LDAP's features but has some own too.
With Net_LDAP2 you have:
 * A simple object-oriented interface to connections, searches entries and filters.
 * Support for tls and ldap v3.
 * Simple modification, deletion and creation of ldap entries.
 * Support for schema handling.

Net_LDAP2 layers itself on top of PHP's existing ldap extensions.

%prep
%setup -q -n %{pear_name}-%{version}
# move package.xml when needed
[ -f ../package.xml ] &&  mv ../package.xml . || :

%build

%install
%{__pear} install --nodeps --offline --packagingroot %{buildroot} package.xml
install -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml

%{php_pear_gen_filelist}

%post
if [ "$1" = "1" ]; then
  # on "rpm -ivh"
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml || :
fi
if [ "$1" = "2" ]; then
  # on "rpm -Uvh"
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml || :
fi

%postun
if [ "$1" = "0" ]; then
  # on "rpm -e"
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name} || :
fi

%files -f %{name}.files
%docdir %{pear_docdir}
%exclude %{pear_metadir}/.??*
%exclude %{pear_testdir}

%changelog
* Thu Dec  5 2019 Arjen de Korte <suse+build@de-korte.org>
- make package PHP version independent
- use correct macro to reference metadata (boo#1158112)
- clean-up spec, use https for downloading
- remove LICENSE file
* Sun Sep 10 2017 jweberhofer@weberhofer.at
- Fixed Group
* Sun Sep  3 2017 jweberhofer@weberhofer.at
- Removed php7-pear-Net_LDAP2-2.2.0-package.xml.patch
- Cleaned up spec
* Thu Aug 17 2017 ecsos@opensuse.org
- renamed package to php7-pear_Net_LDAP2
* Mon Jan 11 2016 aj@ajaissle.de
- Updated spec
- Updated dependencies
- Added php5-pear-Net_LDAP2-2.2.0-package.xml.patch to allow
  installing with php5-pear < 1.10.1
* Sat Jan  9 2016 ecsos@opensuse.org
- update to 2.2.0
  * Fix bug #20969: Fatal error with PEAR 1.10.0 / constructor
    visiblity
  * Add support for PHP 7
  * Improve unit tests
* Sat Mar  1 2014 lars@linux-schulserver.de
- update to 2.1.0
  * New feature: Filter::matches() can do simple filtering on entry
    sets (supported: equals, contain, begin, end, any; NOT, AND, OR.
    Filtering is simple based on regexp, no schema checks and
    matchRules yet!)
  * Fixed minor bugs in Filter, LDAP and Entry class
  * Util::split_attribute_string(): Added support for extended
    match operators from filters
  * Util::split_attribute_string(): Added support for
    delimeter retrieval
- provide php-pear-Net_LDAP2
* Fri Feb  1 2013 aj@ajaissle.de
- New upstream release 2.0.12
  * inmproved performance with large search results
  * Fixed some minor issues with Net_LDAP2_Filter and Net_LDAP2->dnExists()
  * Added NOT filter to Net_LDAP2_Filter::create() so negating is more easily now
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Feb  7 2011 lang@b1-systems.de
- Added license file
* Mon Jan 31 2011 lang@b1-systems.de
- LGPLv3 license
* Wed Jan 26 2011 lang@b1-systems.de
- add dependency on php pecl module ldap as stated in pear
* Wed Jan 26 2011 lang@b1-systems.de
- packaged with php-macros and a template spec
